@@ -9,7 +9,7 @@ int add(int i, int j) {
 
 namespace py = pybind11;
 
-PYBIND11_MODULE(bitblaster, m) {
+PYBIND11_MODULE(bitblaster_core, m) {
     m.doc() = R"pbdoc(
         Pybind11 example plugin
         -----------------------
